@@ -10,19 +10,19 @@ import datetime
 from importlib.metadata import version, PackageNotFoundError
 import subprocess
 from pprint import pprint
+import os
 
 from mulch.decorators import with_logging
 from mulch.workspace_manager_generator import WorkspaceManagerGenerator
 from mulch.workspace_instance_factory import WorkspaceInstanceFactory, load_scaffold
 from mulch.logging_setup import setup_logging, setup_logging_portable
-from mulch.helpers import open_editor, calculate_nowtime_foldername, get_default_untitled_workspace_name_based_on_operating_system, get_global_config_path, index_to_letters, get_username_from_home_directory
+from mulch.helpers import dedupe_paths, open_editor, calculate_nowtime_foldername, get_local_appdata_path, get_default_untitled_workspace_name_based_on_operating_system, get_global_config_path, index_to_letters, get_username_from_home_directory
 from mulch.commands.dotfolder import create_dot_mulch
 from mulch.commands.build_dotmulch_standard_contents import build_dotmulch_standard_contents
 from mulch.constants import FALLBACK_SCAFFOLD, LOCK_FILE_NAME, DEFAULT_SCAFFOLD_FILENAME
 from mulch.workspace_status import WorkspaceStatus
 from mulch.scaffold_loader import load_scaffold, load_scaffold_file, resolve_scaffold
 
-
 logging.basicConfig(level=logging.INFO, format="%(levelname)s: %(message)s")
 logger = logging.getLogger(__name__)
 
@@ -31,18 +31,16 @@ HELP_TEXT = "Mulch CLI for scaffolding Python project workspaces."
 SCAFFOLD_TEMPLATES_FILENAME = 'mulch-scaffold-template-dictionary.toml'
 
 FILENAMES_OF_RESPECT = [
-    'mulch.toml'#,
-    #'mulch-scaffold.toml',
-    #'mulch-scaffold.json'
+    'mulch.toml'
 ]
 
 # Paths are checked in order of respect for loading the scaffold template dictionary.
 # These are used when running `mulch file`, `mulch show`, or any command needing layout templates.
 ORDER_OF_RESPECT = [
-    Path('.mulch'),
-    Path('.'),
-    Path.home() / 'mulch'#,
-    #get_global_config_path(appname="mulch")
+    Path('.mulch'), # project local hidden folder
+    Path.home() / '.mulch', # user profile hidden folde
+    get_local_appdata_path("mulch"), # OS standard config path
+    get_global_config_path("mulch") # Roaming AppData on Windows, ~/.config on Linux/macOS
 ]
 maybe_global = get_global_config_path(appname="mulch")
 if maybe_global:
@@ -105,17 +103,18 @@ def make_dot_mulch_folder(target_dir):
 
 @app.command()
 @with_logging
-def init(
+def src(
     target_dir: Path = typer.Option(Path.cwd(), "--target-dir", "-r", help="Target project root (defaults to current directory)."),
-    enforce_mulch_folder: bool = typer.Option(False,"--enforce-mulch-folder-only-no-fallback", "-e", help = "This is leveraged in the CLI call by the context menu Mulch command PS1 to ultimately mean 'If you run Mulch and there is no .mulch folder, one will be generated. If there is one, it will use the default therein.' "),
-    stealth: bool = typer.Option(False, "--stealth", "-s", help="Put source files in .mulch/src/ instead of root/src/. Workspace still built in root."),
+    #enforce_mulch_folder: bool = typer.Option(False,"--enforce-mulch-folder-only-no-fallback", "-e", help = "This is leveraged in the CLI call by the context menu Mulch command PS1 to ultimately mean 'If you run Mulch and there is no .mulch folder, one will be generated. If there is one, it will use the default therein.' "),
+    stealth: bool = typer.Option(False, "--stealth", "-s", help="Put source files in .mulch/src/ instead of root/src/."),
+    force: bool = typer.Option(False, "--force", help="Override existing, forced."),
     ):
     """
-    Build the workspace_manager.py file in the source code, using the mulch-scaffold.json structure or the fallback structure embedded in WorkspaceManagerGenerator.
+    Build the workspace_manager.py file in the source code, using the mulch.tomlstructure or the fallback structure embedded in WorkspaceManagerGenerator.
     Establish a logs folder at root, with the logging.json file.
     """
-    
-    # The enforce_mulch_folder flag allows the _all_order_of_respect_failed to reach the end of the order_of_respect list, such that a generation of a `.mulch` folder is forceable, without an explicit `mulch folder` call. Otherwise, `mulch` as a single context menu command would use some fallback, rather than forcing a `.mulch` folder to be created, which it should if there is not one.
+    '''
+    # The enforce_mulch_folder flag allows the _all_order_of_respect_failed to reach the end of the order_of_respect list, such that a generation of a `.mulch` folder is forceable, without an explicit `mulch workspace` call. Otherwise, `mulch` as a single context menu command would use some fallback, rather than forcing a `.mulch` folder to be created, which it should if there is not one.
     # The `mulch` command by itself in the context menu means either 
     if enforce_mulch_folder:
         try:
@@ -131,12 +130,13 @@ def init(
         order_of_respect_local = ORDER_OF_RESPECT
     else:
         order_of_respect_local = [Path.cwd() / '.mulch']
-    
+    '''
+    order_of_respect_local = ORDER_OF_RESPECT
     if _all_order_of_respect_failed(order_of_respect_local):
-       make_dot_mulch_folder(target_dir = Path.cwd()) # uses the same logic as the `mulch folder` command. The `mulch file` command must be run manually, for that behavior to be achieved but otherwise the default is the `.mulch` manifestation. This should contain a query tool to build a `mulch-scaffold.toml` file is the user is not comfortable doingediting it themselves in a text editor.
+       make_dot_mulch_folder(target_dir = Path.cwd()) # uses the same logic as the `mulch workspace` command. The `mulch file` command must be run manually, for that behavior to be achieved but otherwise the default is the `.mulch` manifestation. This should contain a query tool to build a `mulch-scaffold.toml` file is the user is not comfortable doingediting it themselves in a text editor.
 
     scaffold_data = resolve_scaffold(order_of_respect_local, FILENAMES_OF_RESPECT)
-    pprint(scaffold_data)
+    #pprint(scaffold_data)
 
     # Create lock data
     lock_data = {
@@ -148,22 +148,22 @@ def init(
     
     print(f"stealth = {stealth}")
     #manager_status = wf.evaluate_manager_status() # check the lock file in src/-packagename-/mulch.lock, which correlates with the workspacemanager
-    mgf = WorkspaceManagerGenerator(target_dir, lock_data, stealth=stealth)
+    mgf = WorkspaceManagerGenerator(target_dir, lock_data, stealth=stealth, force=force)
     was_source_generated = mgf.build_src_components()
     if was_source_generated:
         typer.secho(f"📁 Source code created", fg=typer.colors.BRIGHT_GREEN)
 
 class NamingPattern(str,Enum):
     date = "date"
-    os = "os"
+    new = "new"
 
 def get_folder_name(pattern: NamingPattern = 'date', base_name: str = "New workspace", workspaces_dir: Path = Path.cwd() / "workspaces") -> str:
     '''
     Dynamically generate a workspace folder name based on the chosen pattern.
     Implementation, if the '--name' flag is not used with `mulch workspace`:
      - Default to {date}, and then {date}b, {date}c, {date}d
-     - If the '--pattern os' is used when calling `mulch workspace`, the generated name will be 'New workspace', then 'New workspace (2)', etc, if Windows.   
-     - 'mulch workspace --pattern os --here' will be used as the default register context menu command for 'mulch workspace', using the mulch-workspace.reg file. 
+     - If the '--pattern new' is used when calling `mulch workspace`, the generated name will be 'New workspace', then 'New workspace (2)', etc, if Windows.   
+     - 'mulch workspace --pattern new --here' will be used as the default register context menu command for 'mulch workspace', using the mulch-workspace.reg file. 
     '''
     
     if pattern == NamingPattern.date:
@@ -187,15 +187,15 @@ def get_folder_name(pattern: NamingPattern = 'date', base_name: str = "New works
 @with_logging
 def workspace(
     target_dir: Path = typer.Option(Path.cwd(), "--target-dir", "-r", help="Target project root (defaults to current directory)."),
-    pattern: NamingPattern = typer.Option(NamingPattern.date, help = "Choose naming pattern: 'date' for YYY_MMMMM_DD, or 'name' for 'New workspace (n)'"),
+    pattern: NamingPattern = typer.Option(NamingPattern.date, "--pattern", "-p",  help = "Choose naming pattern: 'date' for YYY_MMMMM_DD, or 'name' for os-specific pattern like 'New workspace (n)'"),
     name: str = typer.Option(None, "--name", "-n", help="Name of the workspace to create."),
-    here: bool = typer.Option(False, "--here", "-h", help="The new named workspace directory should be placed immediately in the current working directory, rather than nested within a `/workspaces/` directory. The `--here` flag can only be used with the `--bare` flag."),
+    here: bool = typer.Option(False, "--here", "-h", help="The new named workspace directory should be placed immediately in the current working directory, rather than nested within a `/workspaces/` directory."),
     set_default: bool = typer.Option(True, "--set-default/--no-set-default", help="Write default-workspace.toml"),
-    enforce_mulch_folder: bool = typer.Option(False,"--enforce-mulch-folder-only-no-fallback", "-e", help = "This is leveraged in the CLI call by the context menu Mulch command PS1 to ultimately mean 'If you run Mulch and there is no .mulch folder, one will be generated. If there is one, it will use the default therein.' "),
+    #enforce_mulch_folder: bool = typer.Option(False,"--enforce-mulch-folder-only-no-fallback", "-e", help = "This is leveraged in the CLI call by the context menu Mulch command PS1 to ultimately mean 'If you run Mulch and there is no .mulch folder, one will be generated. If there is one, it will use the default therein.' "),
     stealth: bool = typer.Option(False, "--stealth", "-s", help="Put workspace in .mulch/workspaces/ instead of root/workspaces/."),
     ):
     """
-    Initialize a new workspace folder tree, using the mulch-scaffold.json structure or the fallback structure embedded in WorkspaceManagerGenerator.
+    Initialize a new workspace folder tree, using the mulch.tomlstructure or the fallback structure embedded in WorkspaceManagerGenerator.
     """
     # Provide instant feedback on the --here setting.
     if here:
@@ -212,8 +212,8 @@ def workspace(
     if name is None:
         name=get_folder_name(pattern = pattern, workspaces_dir=workspaces_dir)
     
-
-    # The enforce_mulch_folder flag allows the _all_order_of_respect_failed to reach the end of the order_of_respect list, such that a generation of a `.mulch` folder is forceable, without an explicit `mulch folder` call. Otherwise, `mulch` as a single context menu command would use some fallback, rather than forcing a `.mulch` folder to be created, which it should if there is not one.
+    """
+    # The enforce_mulch_folder flag allows the _all_order_of_respect_failed to reach the end of the order_of_respect list, such that a generation of a `.mulch` folder is forceable, without an explicit `mulch workspace` call. Otherwise, `mulch` as a single context menu command would use some fallback, rather than forcing a `.mulch` folder to be created, which it should if there is not one.
     # The `mulch` command by itself in the context menu means either 
     if enforce_mulch_folder:
         try:
@@ -228,10 +228,10 @@ def workspace(
         order_of_respect_local = ORDER_OF_RESPECT
     else:
         order_of_respect_local = [Path.cwd() / '.mulch']
-    
-    
+    """
+    order_of_respect_local = ORDER_OF_RESPECT
     if _all_order_of_respect_failed(order_of_respect_local):
-       make_dot_mulch_folder(target_dir = Path.cwd()) # uses the same logic as the `mulch folder` command. The `mulch file` command must be run manually, for that behavior to be achieved but otherwise the default is the `.mulch` manifestation. This should contain a query tool to build a `mulch-scaffold.toml` file is the user is not comfortable doingediting it themselves in a text editor.
+       make_dot_mulch_folder(target_dir = Path.cwd()) # uses the same logic as the `mulch workspace` command. The `mulch file` command must be run manually, for that behavior to be achieved but otherwise the default is the `.mulch` manifestation. This should contain a query tool to build a `mulch-scaffold.toml` file is the user is not comfortable doingediting it themselves in a text editor.
 
     scaffold_data = resolve_scaffold(order_of_respect_local, FILENAMES_OF_RESPECT)
     pprint(scaffold_data)
@@ -244,7 +244,7 @@ def workspace(
         "generated_by": get_username_from_home_directory()
     }
     
-    print(f"workspace_dirs = {workspaces_dir}")
+    logger.DEBUG(f"workspace_dirs = {workspaces_dir}")
     '''# Check if workspace already exists
     if workspace_dir.exists():
         typer.secho(f"⚠️ Workspace '{name}' already exists at {workspaces_dir}", fg=typer.colors.YELLOW)
@@ -284,40 +284,43 @@ def context():
     """
     Install the right-click `mulch workspace` context menu registry item by calling install.py 
     """
-    from src.scripts.install import install_context
+    from mulch.scripts.install import install_context
     install_context.setup()
 
+from rich.table import Table
+from rich.console import Console
 
 #@with_logging(use_portable=True)
 @app.command()
 def order(
     target_dir: Path = typer.Option(Path.cwd(), "--target-dir", "-t", help="Target project root (defaults to current directory)."),
-    ):
+):
     """
-    Determine the ordered list of available fallbacks. 
-    You can then request to see contents from an identifying number as a CLI input.
+    Show the ordered list of mulch scaffold search paths and indicate which exist.
     """
-    typer.echo("Coming soon :)")
-    '''typer.echo(""" \n
-               1. Path(.mulch) / 'mulch.toml' \n
-               2. Path('.') / 'mulch.toml' \n
-               3. Path.home() / 'mulch' / 'mulch.toml' \n
-               \n
-               \n
-               Available: 1, 3.
-               If you would like, select an option to display the contents. \n
-               \n
-               
-               
-               """)
-    '''
-    typer.echo(f"ORDER_OF_RESPECT = {ORDER_OF_RESPECT}")
-    typer.echo(f"FILENAMES_OF_RESPECT = {FILENAMES_OF_RESPECT}")
-    typer.echo()
-    typer.confirm("If you would like, select an option to display the contents.")
-    typer.Option("If you would like, select an option to display the contents.",rich_help_panel=True )
-    #typer.run()
+    console = Console()
 
+    table = Table(title="Mulch Scaffold Order of Respect")
+
+    table.add_column("Index", justify="right", style="cyan", no_wrap=True)
+    table.add_column("Path", style="magenta")
+    table.add_column("Exists?", justify="center", style="green")
+
+    unique_order_of_respect = dedupe_paths(ORDER_OF_RESPECT)
+
+    typer.echo(f"DEBUG ORDER_OF_RESPECT list:")
+    for idx, p in enumerate(unique_order_of_respect):
+        typer.echo(f"  {idx+1}: {p} ({p.resolve() if p.exists() else 'does not exist'})")
+
+
+    for i, path in enumerate(unique_order_of_respect, start=1):
+        base_path = (target_dir / path) if not path.is_absolute() else path
+        resolved_path = (base_path / "mulch.toml").resolve()
+        exists = resolved_path.exists()
+        table.add_row(str(i), str(resolved_path), "✅" if exists else "❌")
+
+    console.print(table)
+    
 def load_template_choice_dictionary_from_file():
     """
     Attempts to load a TOML or JSON template choice dictionary from known fallback paths.
@@ -372,14 +375,14 @@ def seed(#def dotmulch(
         open_editor(scaffold_path)
 
     typer.secho("✏️  You can now manually edit the folder contents to customize your workspace layout and other mulch configuration.",fg=typer.colors.WHITE)
-    typer.echo("⚙️  Changes to the scaffold file will directly affect the workspace layout and the generated workspace_manager.py when you run 'mulch init'.")
+    typer.echo("⚙️  Changes to the scaffold file will directly affect the workspace layout and the generated workspace_manager.py when you run 'mulch src'.")
     
     build_dotmulch_standard_contents(target_dir = Path.cwd())
 
 @app.command()
-def show(
+def show_(
     filepath: Path = typer.Option(
-        None, "--filepath", "-f", help="Path to an explicit scaffold JSON file."
+        None, "--filepath", "-f", help="Path to an explicit scaffold TOML file."
     ),
     use_default: bool = typer.Option(
         False, "--use-default-filepath", "-d", help=f"Reference the default filepath .\{DEFAULT_SCAFFOLD_FILENAME}."
@@ -392,7 +395,7 @@ def show(
     ),
     ):
     """
-    Display the fallback scaffold dictionary structure or load and display a scaffold JSON file.
+    Display the fallback scaffold dictionary structure or load and display a scaffold TOML file.
     """
     default_path = Path.cwd() / DEFAULT_SCAFFOLD_FILENAME
 
@@ -433,6 +436,46 @@ def show(
         typer.echo(json.dumps(scaffold, separators=(",", ":")))
     else:
         typer.echo(json.dumps(scaffold, indent=2))
-    
+
+
+@app.command()
+def show(index: int = typer.Argument(None, help="Index from 'mulch order' to display")):
+    """
+    Show the scaffold from the first available source in the order of respect,
+    or from the specific index if provided.
+    """
+    # Prepare the order of respect unique and resolved paths
+    unique_order_of_respect = dedupe_paths(ORDER_OF_RESPECT)
+
+    # If an index is given, adjust to 0-based and target that path
+    if index is not None:
+        if index < 1 or index > len(unique_order_of_respect):
+            raise typer.Exit(f"Invalid index {index}. Run 'mulch order' to see valid indices.")
+        candidate_dir = unique_order_of_respect[index - 1]
+        paths_to_check = [candidate_dir]
+    else:
+        # Otherwise, check in priority order
+        paths_to_check = unique_order_of_respect
+
+    for candidate in paths_to_check:
+        path = Path(candidate) / "mulch.toml"
+        if path.exists():
+            typer.echo(f"Loaded scaffold from: {path}")
+            if path.suffix.lower() == ".toml":
+                
+                with open(path, "r", encoding="utf-8") as f:
+                    scaffold = toml.load(f)
+            else:
+                raise typer.Exit(f"Unsupported scaffold file format: {path.suffix}")
+
+            print(toml.dumps(scaffold))
+            return
+
+    # Fallback
+    scaffold = load_scaffold_file()  # Your embedded fallback
+    print("Loaded scaffold from embedded fallback structure.")
+    print(toml.dumps(scaffold))
+
+
 if __name__ == "__main__":
     app()
